use i18n::{message, message_ids::MessageId};
use library::{
    context::Context,
    model::response::{ResErr, ResResult},
    social::wechat::{MiniAppLoginResult, WeChatAccessToken, WECHAT_SOCIAL},
};

pub async fn get_wechat_access_token(context: Context) -> ResResult<WeChatAccessToken> {
    let lang_tag = context.get_lang_tag();
    let access_token = match WECHAT_SOCIAL.get_access_token().await {
        Ok(access_token) => access_token,
        Err(err) => {
            tracing::error!("获取微信access_token失败,err:{}", err);
            return Err(ResErr::service(message!(
                lang_tag,
                MessageId::FailedGetWxAaccessToken
            )));
        }
    };
    Ok(access_token)
}

pub async fn code_2_session(context: Context, code: String) -> ResResult<MiniAppLoginResult> {
    let lang_tag = context.get_lang_tag();
    let result = match WECHAT_SOCIAL.code_2_session(&code).await {
        Ok(result) => result,
        Err(err) => {
            tracing::error!("微信登录失败,err:{}", err);
            return Err(ResErr::service(message!(
                lang_tag,
                MessageId::FailedWeChatLogin
            )));
        }
    };
    Ok(result)
}
